import React, { Component } from 'react';
import { Modal, Row, Col, Button, Form } from 'antd';
import CustomTransfer from './CustomTransfer';
import _ from 'lodash';
const titles = ['可选', '已选'];

function RedStar() {
	return <span style={{ color: 'red' }}>*</span>;
}

class CustomColumnsModal extends Component {
	static defaultProps = {
		columnKeys: [],
		fixCols: 0,
	};

	constructor(props) {
		super(props);
		this.state = this.getInitState(props);
	}

	componentWillReceiveProps(nextProps) {
		this.setState(this.getInitState(nextProps));
	}

	getInitState = (props = this.props) => {
		let customColumns = props.customColumns || [];
		let targetKeys = [];
		let dataSource = [];
		let requiredKeys = [];
		customColumns.forEach(item => {
			if (item.required === true || item.required === 'true') {
				requiredKeys.push(item.dataIndex);
			}
			if (item.orderNo > 0) {
				targetKeys.push(item.dataIndex);
			}
			let data = {
				key: item.dataIndex,
				...item,
			};
			dataSource.push(data);
		});
		return {
			dataSource,
			targetKeys,
			fixCols: props.fixCols,
			selectedKeys: [],
			visible: false,
			requiredKeys
		};
	};

	handleOk = () => {
		const { columnKeys } = this.props;
		const { targetKeys, selectedKeys, dataSource, ...values } = this.state;
		values.columnKeys = targetKeys.map(key => {
			return columnKeys.filter(info => info.dataIndex === key)[0] || { key };
		});
		this.props.onOk(values);
	};

	handleSelectChange = ({ key }, checked) => {
		let { selectedKeys, targetKeys } = this.state;
		let _selectedKeys = _.cloneDeep(selectedKeys);
		const checkedLen = checked.length;
		const targetKeysLen = targetKeys.length;
		if (Array.isArray(checked)) {
			if (checkedLen === 0) {
				_selectedKeys = [];
			} else {
				if (checkedLen === targetKeysLen) {
					_selectedKeys = checked;
				}
			}
		} else {
			if (targetKeys.indexOf(key) > -1) {
				if (checked) {
					_selectedKeys = _selectedKeys.concat(key);
				} else {
					_selectedKeys = _selectedKeys.filter(item => item !== key);
				}
			}
		}
		this.setState({ selectedKeys: _selectedKeys });
	};

	handleTransferChange = (targetKeys, direction, moveKeys) => {
		let newTargetKeys = this.state.targetKeys;
		if (direction === 'left') {
			this.setState({ selectedKeys: [] });
			// 必选字段是无法移动的
			moveKeys = moveKeys.filter(key => !this.state.requiredKeys.includes(key));
			newTargetKeys = newTargetKeys.filter(key => moveKeys.indexOf(key) === -1);
		} else {
			newTargetKeys = newTargetKeys.concat(moveKeys);
		}
		this.setState({ targetKeys: newTargetKeys });
	};

	handleFixColsChange = value => {
		this.setState({ fixCols: value });
	};

	handleMoveUp = () => {
		const { selectedKeys, targetKeys } = this.state;
		const selectedKey = selectedKeys[0];
		const tmp = targetKeys.concat();
		const idx = tmp.indexOf(selectedKey);
		if (idx !== 0) {
			const targetIdx = idx - 1;
			const targetKey = tmp[targetIdx];
			tmp[targetIdx] = selectedKey;
			tmp[idx] = targetKey;
			this.setState({ targetKeys: tmp });
		}
	};

	handleMoveDown = () => {
		const { selectedKeys, targetKeys } = this.state;
		const selectedKey = selectedKeys[0];
		const tmp = targetKeys.concat();
		const idx = tmp.indexOf(selectedKey);
		if (idx + 1 !== tmp.length) {
			const targetIdx = idx + 1;
			const targetKey = tmp[targetIdx];
			tmp[targetIdx] = selectedKey;
			tmp[idx] = targetKey;
			this.setState({ targetKeys: tmp });
		}
	};

	handleMoveTop = () => {
		const { selectedKeys, targetKeys } = this.state;
		const newTargetKeys = _.cloneDeep(targetKeys);
		const tmp = new Set(selectedKeys.concat(newTargetKeys));
		const newTmp = [...tmp];
		this.setState({ targetKeys: newTmp });
	};

	renderItem = item => {
		const customLabel = (
			<span>
				<span style={{ marginRight: 2 }}>{item.required === true || item.required === 'true' ? <RedStar /> : ' '}</span>
				{item.title}
			</span>
		);
		return {
			label: customLabel, // for displayed item
			value: item.title, // for title and filter matching
		};
	};

	handleShow = () => {
		this.setState({ visible: true });
	};

	handleClose = () => {
		this.setState({ visible: false });
	};

	render() {
		const { dataSource, targetKeys, selectedKeys } = this.state;
		const { visible, onCancel } = this.props;
		const footer = (
			<div className="footer-btn-layout">
				<button key="cancel" className="ant-btn ant-btn-lg" onClick={onCancel}>
					取 消
				</button>
				<button key="ok" className="ant-btn ant-btn-primary ant-btn-lg" onClick={this.handleOk}>
					确 定
				</button>
			</div>
		);

		const modalOpts = {
			className: 'table-custom-column',
			maskClosable: false,
			visible,
			onCancel,
			footer,
		};

		const canMove = selectedKeys.length === 1;
		const canMoveTop = selectedKeys.length >= 1;
		const btnType = canMove ? 'primary' : 'default';
		const toTopBtnType = canMoveTop ? 'primary' : 'default';
		const isFirst = canMove && targetKeys[0] === selectedKeys[0];
		const isLast = canMove && targetKeys.length > 1 && targetKeys[targetKeys.length - 1] === selectedKeys[0];

		const upBtnProps = {
			icon: 'up',
			size: 'small',
			type: btnType,
			disabled: isFirst || !canMove,
			onClick: this.handleMoveUp,
		};

		const downBtnProps = {
			icon: 'down',
			size: 'small',
			type: btnType,
			disabled: isLast || !canMove,
			onClick: this.handleMoveDown,
		};
		const toTopProps = {
			onClick: this.handleMoveTop,
			size: 'small',
			key: 'toTop',
			type: toTopBtnType,
			disabled: !canMoveTop,
			style: { marginTop: '4px' },
		};

		return (
			<Button {...this.props.buttonProps} onClick={this.handleShow}>
				自定义列
				<Modal {...modalOpts} onCancel={this.handleClose} visible={this.state.visible}>
					<Row>
						<Col span={20}>
							<CustomTransfer
								showSearch
								titles={titles}
								listStyle={{ width: 180, height: 300 }}
								targetKeys={targetKeys}
								dataSource={dataSource}
								render={this.renderItem}
								onSelectChange={this.handleSelectChange}
								onChange={this.handleTransferChange}
							/>
						</Col>
						<Col span={2}>
							<div className="ant-transfer-operation transfer-updown ">
								<Button {...upBtnProps} />
								<Button {...downBtnProps} />
								<Button {...toTopProps}>置顶</Button>
							</div>
						</Col>
					</Row>
				</Modal>
			</Button>
		);
	}
}

export default Form.create()(CustomColumnsModal);
