import React, { Component } from 'react';

import { Row, Col, OlymTable as ATable } from 'antd';
import PropTypes from 'prop-types';

import CustomColumnsModal from './CustomColumnsModal';
import _ from 'lodash';
import utils from './utils';
import constants from './constants';
import api from './api';
import Message from '../../antd/message';

import './style.css';
import '../styles/common.less';
import '../../antd/message/style';

export default class Table extends Component {
  constructor(props) {
    super(props);
    this.state = {
      visible: false,
      timeId: new Date().valueOf(),
    };
  }

  componentDidMount = () => {
    if (this.isCustomizeColumnTable()) {
      this.fetchCustomColumns();
    }
    //设置拖拽
    utils.setDraggableColumns(this);
  };

  isCustomizeColumnTable = () => {
    return this.props.customVo && this.props.fetchDataSource;
  }

  onShowSizeChange = (current, size) => {
    await api.saveCustomPageSize(size);
    this.props.fetchDataSource(utils.updatePaginationWithPageSize(size));
  }

  updatePaginationWithPageSize = (pageSize, current = 1) => {
    let pagination = {
      pageSize,
      current,
      showTotal: (total) => {
        return `共${total}条，每页${pageSize}条`
      },
      showQuickJumper: true,
      showSizeChanger: true,
      pageSizeOptions: ['10', '15', '30', '50', '100'],
      onShowSizeChange: this.onShowSizeChange,
    };
    return pagination;
  }

  fetchCustomColumns = async () => {
    let result = await api.getCustomLine(this.props.customVo);
    let { columns, tableWidth } = this.props.getColumns(result);
    this.setState({
      pagination: utils.updatePaginationWithPageSize(_.result(result, 'userSet.pageSize', 15)),
      columns,
      tableWidth,
    });
  }

  saveCustomColumns = async selectedColumns => {
    let { customVo } = this.props
    const comPortletSetVo = {
      ...customVo
    }
    let columns = []
    selectedColumns &&
      selectedColumns.columnKeys.forEach(obj => {
        if (obj.dataIndex !== 'cao_zuo_id') {
          columns.push({
            elementName: obj.dataIndex
          })
        }
      })
    comPortletSetVo.columns = JSON.stringify(columns)

    await api.saveCustomLine(comPortletSetVo);
    Message.success('自定义列保存成功！');
    this.props.fetchCustomColumns();
    this.props.refreshPage();
  }

  //设置可拖拽控制宽度
  componentDidUpdate = () => {
    utils.setDraggableColumns(this);
  };

  shouldComponentUpdate(nextProps, nextState) {
    if (_.isEqual(nextProps, this.props) && _.isEqual(nextState, this.state)) {
      return false;
    } else {
      return true;
    }
  }

  getUserDefineCol = (columns, customColumns) => {
    if (!customColumns || customColumns.length === 0) {
      return _.extend([], columns);
    }
    let userDefineColumns = [];
    let customColumnsMap = {};
    customColumns.map(col => {
      customColumnsMap[col.dataIndex] = col;
    });
    let extraColumns = [];
    columns.map(obj => {
      const dataIndex = obj.dataIndex;
      if (!obj.key) {
        obj.key = obj.dataIndex;
      }
      if (customColumnsMap[dataIndex]) {
        const customCol = customColumnsMap[dataIndex];
        if (customCol.orderNo && customCol.orderNo > -1) {
          obj.orderNo = customColumnsMap[dataIndex].orderNo;
          userDefineColumns.push(obj);
        }
      } else {
        extraColumns.push(obj);
      }
    });
    userDefineColumns = userDefineColumns.concat(extraColumns);
    userDefineColumns.sort((a, b) => {
      return a.orderNo - b.orderNo;
    });
    return userDefineColumns;
  };

  getDataSource = () => {
    let { showSeq, dataSource } = this.props;
    if (showSeq) {
      return dataSource.map((item, index) => {
        return {
          ...item,
          'DZG_SEQ_COLUMN': index + 1,
        }
      });
    }
    return dataSource;
  }

  getCustomColumns = () => {
    let { customColumns } = this.props;
    let _customColumns = [];
    customColumns &&
      customColumns.map(col => {
        const { orderNo, dataIndex, title } = col;
        _customColumns.push({ orderNo, dataIndex, title });
      });
    _customColumns.sort((a, b) => {
      return a.orderNo - b.orderNo;
    });
    return _customColumns;
  }

  getUserDefinedColumns = (customColumns) => {
    let { columns, showSeq, dataSource } = this.props;
    let userDefineColumns = this.getUserDefineCol(columns, customColumns);
    let _dataSource;

    if (showSeq) {
      //显示序号
      _dataSource = [];
      dataSource.forEach((data, index) => {
        _dataSource.push({
          'DZG_SEQ_COLUMN': index + 1,
          ...data,
        });
      });
      userDefineColumns.unshift({
        dataIndex: 'DZG_SEQ_COLUMN',
        key: 'DZG_SEQ_COLUMN',
        title: '序号',
        width: 50,
        render: (text, record, index) => {
          return <div key={`DZG_SEQ_COLUMN_${index}`} style={{ display: 'flex', justifyContent: 'center' }}>{text}</div>;
        },
      });
    }
    return userDefineColumns;
  }

  getTableTitle = () => {
    let {
      leftSpan = 6,
      rightSpan = 18,
      selectedRowKeysCount = 0,
      title,
      onCustomChange,
      customCtns,
    } = this.props;
    let customColumns = this.getCustomColumns();
    const left = () => {
      let leftChildren = [];
      if (title) {
        if (typeof title === 'string') {
          leftChildren.push(<b key="table_title">{title}</b>);
        } else {
          leftChildren.push(title);
        }
      }
      if (customColumns && Array.isArray(customColumns) && customColumns.length > 0) {
        const buttonProps = {
          size: 'small',
          key: 'custom',
        };
        if (title) {
          buttonProps.className = 'ml8';
        }
        // 弹出框参数
        const modalOpts = {
          columnKeys: customColumns,
          onOk: onCustomChange,
          customColumns,
        };
        leftChildren.push(<CustomColumnsModal key="custom_columns" buttonProps={buttonProps} {...modalOpts} />);
      }
      //选中条数
      if (!!selectedRowKeysCount) {
        leftChildren.push(<span key="count">&nbsp;&nbsp;已选择{selectedRowKeysCount}项</span>);
      }
      if (leftChildren.length === 0) {
        return;
      }
      return (
        <div className="tal" key="leftarea">
          {leftChildren}
        </div>
      );
    };
    const right = () => {
      let rightChildren = [];
      if (customCtns && Array.isArray(customCtns) && customCtns.length > 0) {
        customCtns.map(btn => {
          const { props, ...others } = btn;
          const _btn = {
            props: {
              ...props,
              className: 'custom_other_btn_right',
            },
            ...others,
          };
          rightChildren.unshift(_btn);
        });
        return (
          <div className="tar" key="rightarea">
            {rightChildren}
          </div>
        );
      } else if (customCtns && typeof customCtns === 'function') {
        return (
          <div className="tar" key="rightarea">
            {customCtns()}
          </div>
        );
      }
    };
    return (
      <Row>
        <Col key="left" span={leftSpan}>{left()}</Col>
        <Col key="right" span={rightSpan}>{right()}</Col>
      </Row>
    );
  }

  render() {
    const {
      customCtns,
      title,
    } = this.props;
    const { timeId } = this.state;
    let customColumns = this.getCustomColumns();
    //把处理完的数据组合成新的props
    let props = {
      ..._.pick(this.props, constants.antDTableKeys),
      dataSource: this.getDataSource(),
      columns: this.getUserDefinedColumns(customColumns),
    };
    if (title || customCtns || (customColumns && customColumns.length > 0)) {
      props.title = this.getTableTitle;
    }

    //scroll
    if (props.scroll && props.scroll.y) {
      let className = props.className || '';
      className += ' ant-table-scroll-y';
      props.className = className;
    }

    return (
      <div id={timeId}>
        <ATable {...props} />
      </div>
    );
  }
}

Table.propTypes = {
  columns: PropTypes.array, // table列参数
  customVo: PropTypes.shape({
    // 获取自定义列请求参数
    appCode: PropTypes.string,
    modelId: PropTypes.string,
    pageName: PropTypes.string,
    portletName: PropTypes.string,
  }),
  tableColumnRender: PropTypes.func, // table render
  onCustomInfoChange: PropTypes.func, // 自定义列信息变更后的回调
  adTableOnColumnChange: PropTypes.func, // 列变动时触发
  adTableOnCustomColumnChange: PropTypes.func, // 自定义列变动时触发
  staticColumns: PropTypes.array, // 不可自定义的列
};
