import "fetch-detector";
import "fetch-ie8";
import Base64 from './Base64';
import Message from '../../antd/message';
import '../../antd/message/style';

let btnLeftTime = 0;

function checkBtnCanClick() {
    return btnLeftTime == 0 ? true : false;
}

function setBtnLeftTime(time) {
    btnLeftTime = time;
    setTimeout(() => { btnLeftTime = 0 }, time * 1000 + 500);
}

function showMessage(msg, type, time) {
    if (checkBtnCanClick()) {
        if (type === 'success') {
            Message.success(msg, time ? time : 2);
            setBtnLeftTime(time ? time : 2);
        } else if (type === 'error') {
            Message.error(msg, time ? time : 2);
            setBtnLeftTime(time ? time : 2);
        } else if (type === 'warning') {
            Message.warning(msg, time ? time : 2);
            setBtnLeftTime(time ? time : 2);
        }
    }
};

const rquery = /\?/;

function parseJSON(response) {
    return response.json();
}

function checkStatus(response) {
    if (response.status >= 200 && response.status < 300) {
        return response;
    }

    checkDcas(response);

    const error = new Error(response.statusText);
    error.response = response;
    throw error;
}

function checkErrCode(json) {
    if (Number(json.resultCode) == 420) {
        goToLogin(json);
    } else if (Number(json.resultCode) == 506) {
        showMessage(json.resultMsg, 'error');
        const error = new Error(json.resultMsg);
        throw error;
    } else {
        return json;
    }
}

function goToLogin(json) {
    let { dcasStateValiURL, backurl } = json;
    backurl = `${location.protocol}//${location.host}/membership/redirect`;
    // 添加backurl
    backurl += `${rquery.test(backurl) ? '&' : '?'}target=${encodeURI(Base64.encodeUrlsafe(encodeURI(location.href)))}`;
    dcasStateValiURL += `${rquery.test(dcasStateValiURL) ? '&' : '?'}backurl=${Base64.encodeUrlsafe(backurl)}`;
    // 直接跳转到dcas验证
    top.location.href = dcasStateValiURL;
}
/**
 * 检查并处理 dcas 420错误
 * @param response
 */
function checkDcas(response) {

    if (response.status === 420) {
        response.text().then((info) => {
            let jsonData = new Function(`return ${info}`)();
            goToLogin(jsonData);
        });
    }
}

function showLoading() {
    let loading = document.getElementById('loading');
    if (null == loading) {
        let div = document.createElement("div");
        div.id = "loading";
        document.body.appendChild(div);
    }
}

function removeLoading(url) {
    loadingQueue.splice(loadingQueue.indexOf(url), 1)
    let loading = document.getElementById('loading');
    if (null != loading && loadingQueue.length === 0) {
        document.body.removeChild(loading);
    }
}

let loadingQueue = []

/**
 * Requests a URL, returning a promise.
 *
 * @param  {string} url       The URL we want to request
 * @param  {object} [options] The options we want to pass to "fetch"
 * @return {object}           An object containing either "data" or "err"
 */
export default function request(url, options = { method: 'POST' }) {
    const { headers, needLoad, ...other } = options
    const opts = {
        mode: 'cors', // 支持跨域
        credentials: 'include', // 带cookie,
        headers: {
            'X-Requested-With': 'XMLHttpRequest',  // ajax标识
            'Content-Type': 'application/x-www-form-urlencoded;charset=utf-8', // form形式提交
            //authorization: cookie.get('authorization') || '',
            ...headers
        },
        ...other
    };

    if (needLoad) {
        loadingQueue.push(url)
        showLoading();
    }

    return fetch(url, opts)
        .then(checkStatus)
        .then(parseJSON)
        .then(checkErrCode)
        .then(data => { needLoad ? setTimeout(() => removeLoading(url), 50) : null; return data })
        .catch((err) => { needLoad ? setTimeout(() => removeLoading(url), 50) : null; return err; });
}