'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _KeyCode = require('rc-util/lib/KeyCode');

var _KeyCode2 = _interopRequireDefault(_KeyCode);

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var options = [{
  value: 'zhejiang',
  label: 'Zhejiang',
  children: [{
    value: 'hangzhou',
    label: 'Hangzhou',
    children: [{
      value: 'xihu',
      label: 'West Lake'
    }]
  }]
}, {
  value: 'jiangsu',
  label: 'Jiangsu',
  children: [{
    value: 'nanjing',
    label: 'Nanjing',
    children: [{
      value: 'zhonghuamen',
      label: 'Zhong Hua Men'
    }]
  }]
}];

describe('Cascader', function () {
  it('popup correctly when panel is hidden', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { options: options }));
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('popup correctly when panel is open', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { options: options }));
    wrapper.find('input').simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('popup correctly with defaultValue', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { options: options, defaultValue: ['zhejiang', 'hangzhou'] }));
    wrapper.find('input').simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('can be selected', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { options: options }));
    wrapper.find('input').simulate('click');
    var popupWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    popupWrapper.find('.ant-cascader-menu').at(0).find('.ant-cascader-menu-item').at(0).simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
    popupWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    popupWrapper.find('.ant-cascader-menu').at(1).find('.ant-cascader-menu-item').at(0).simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
    popupWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    popupWrapper.find('.ant-cascader-menu').at(2).find('.ant-cascader-menu-item').at(0).simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('backspace should work with `Cascader[showSearch]`', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { options: options, showSearch: true }));
    wrapper.find('input').simulate('change', { target: { value: '123' } });
    expect(wrapper.state('inputValue')).toBe('123');
    wrapper.find('input').simulate('keydown', { keyCode: _KeyCode2.default.BACKSPACE });
    // Simulate onKeyDown will not trigger onChange by default, so the value is still '123'
    expect(wrapper.state('inputValue')).toBe('123');
  });
});