'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _ = require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('RangePicker', function () {
  it('show month panel according to value', function () {
    var birthday = (0, _moment2.default)('2000-01-01', 'YYYY-MM-DD').locale('zh-cn');
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, {
      getCalendarContainer: function getCalendarContainer(trigger) {
        return trigger;
      },
      format: 'YYYY/MM/DD',
      showTime: true,
      open: true
    }));

    wrapper.setProps({ value: [birthday, birthday] });
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('switch to corresponding month panel when click presetted ranges', function () {
    var birthday = (0, _moment2.default)('2000-01-01', 'YYYY-MM-DD').locale('zh-cn');
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, {
      ranges: {
        'My Birthday': [birthday, birthday]
      },
      getCalendarContainer: function getCalendarContainer(trigger) {
        return trigger;
      },
      format: 'YYYY/MM/DD',
      showTime: true,
      open: true
    }));

    var rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    rangeCalendarWrapper.find('.ant-calendar-range-quick-selector a').simulate('click');
    expect((0, _enzyme.render)(wrapper.find('Trigger').node.getComponent())).toMatchSnapshot();
  });

  it('highlight range when hover presetted range', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, {
      ranges: {
        'This Month': [(0, _moment2.default)().startOf('month'), (0, _moment2.default)().endOf('month')]
      },
      getCalendarContainer: function getCalendarContainer(trigger) {
        return trigger;
      },
      format: 'YYYY/MM/DD',
      open: true
    }));

    var rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    rangeCalendarWrapper.find('.ant-calendar-range-quick-selector a').simulate('mouseEnter');
    rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    expect(rangeCalendarWrapper.find('.ant-calendar-selected-day').length).toBe(2);
  });

  // issue: https://github.com/ant-design/ant-design/issues/5872
  it('should not throw error when value is reset to `[]`', function () {
    var birthday = (0, _moment2.default)('2000-01-01', 'YYYY-MM-DD');
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, {
      getCalendarContainer: function getCalendarContainer(trigger) {
        return trigger;
      },
      value: [birthday, birthday],
      open: true
    }));
    wrapper.setProps({ value: [] });
    var rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    expect(function () {
      return rangeCalendarWrapper.find('.ant-calendar-cell').at(15).simulate('click').simulate('click');
    }).not.toThrow();
  });

  // issue: https://github.com/ant-design/ant-design/issues/7077
  it('should not throw error when select after clear', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, {
      getCalendarContainer: function getCalendarContainer(trigger) {
        return trigger;
      },
      open: true
    }));
    var rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    rangeCalendarWrapper.find('.ant-calendar-cell').at(15).simulate('click').simulate('click');
    wrapper.find('.ant-calendar-picker-clear').simulate('click');
    wrapper.find('.ant-calendar-picker-input').simulate('click');
    rangeCalendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    expect(function () {
      return rangeCalendarWrapper.find('.ant-calendar-cell').at(15).simulate('click').simulate('click');
    }).not.toThrow();
  });
});