'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('DatePicker with showTime', function () {
  it('should trigger onChange when select value', function () {
    var onChangeFn = jest.fn();
    var onOpenChangeFn = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { showTime: true, open: true, onChange: onChangeFn, onOpenChange: onOpenChangeFn }));

    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    calendarWrapper.find('.ant-calendar-date').at(0).simulate('click');
    expect(onChangeFn).toHaveBeenCalled();
    expect(onOpenChangeFn).not.toHaveBeenCalled();
  });

  it('should trigger onOk when press ok button', function () {
    var onOkFn = jest.fn();
    var onOpenChangeFn = jest.fn();
    var onChangeFn = jest.fn();

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { showTime: true, open: true, onChange: onChangeFn, onOk: onOkFn, onOpenChange: onOpenChangeFn }));

    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    calendarWrapper.find('.ant-calendar-ok-btn').simulate('click');
    expect(onOkFn).toHaveBeenCalled();
    expect(onOpenChangeFn).toHaveBeenCalledWith(false);
    expect(onChangeFn).not.toHaveBeenCalled();
  });

  it('should trigger onChange when click Now link', function () {
    var onOpenChangeFn = jest.fn();
    var onChangeFn = jest.fn();

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { showTime: true, open: true, onChange: onChangeFn, onOpenChange: onOpenChangeFn }));

    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    calendarWrapper.find('.ant-calendar-today-btn').simulate('click');
    expect(onOpenChangeFn).toHaveBeenCalledWith(false);
    expect(onChangeFn).toHaveBeenCalled();
  });

  it('should have correct className when use12Hours is true', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { showTime: { use12Hours: true }, open: true }));
    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    expect(calendarWrapper.find('.ant-calendar-time-picker-column-4').length).toBe(0);
    calendarWrapper.find('.ant-calendar-time-picker-btn').at(0).simulate('click');
    expect(calendarWrapper.find('.ant-calendar-time-picker-column-4').length).toBe(1);
  });
});

describe('RangePicker with showTime', function () {
  it('should trigger onChange when select value', function () {
    var onChangeFn = jest.fn();
    var onOpenChangeFn = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, { showTime: true, open: true, onChange: onChangeFn, onOpenChange: onOpenChangeFn }));

    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    expect(calendarWrapper.find('.ant-calendar-time-picker-btn').hasClass('ant-calendar-time-picker-btn-disabled')).toBe(true);
    expect(calendarWrapper.find('.ant-calendar-ok-btn').hasClass('ant-calendar-ok-btn-disabled')).toBe(true);
    calendarWrapper.find('.ant-calendar-date').at(10).simulate('click');
    calendarWrapper.find('.ant-calendar-date').at(11).simulate('click');
    expect(calendarWrapper.find('.ant-calendar-time-picker-btn').hasClass('ant-calendar-time-picker-btn-disabled')).toBe(false);
    expect(calendarWrapper.find('.ant-calendar-ok-btn').hasClass('ant-calendar-ok-btn-disabled')).toBe(false);
    expect(onChangeFn).toHaveBeenCalled();
    expect(onOpenChangeFn).not.toHaveBeenCalled();
  });

  it('hould trigger onOk when press ok button', function () {
    var onOkFn = jest.fn();
    var onChangeFn = jest.fn();
    var onOpenChangeFn = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_.RangePicker, { showTime: true, open: true, onOk: onOkFn, onChange: onChangeFn, onOpenChange: onOpenChangeFn }));

    var calendarWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    calendarWrapper.find('.ant-calendar-date').at(10).simulate('click');
    calendarWrapper.find('.ant-calendar-date').at(11).simulate('click');
    onChangeFn.mockClear();
    calendarWrapper.find('.ant-calendar-ok-btn').simulate('click');
    expect(onOkFn).toHaveBeenCalled();
    expect(onOpenChangeFn).toHaveBeenCalledWith(false);
    expect(onChangeFn).not.toHaveBeenCalled();
  });
});