'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Form', function () {
  it('should remove duplicated user input colon', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      null,
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label:' },
        'input'
      ),
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label\uFF1A' },
        'input'
      )
    ));
    expect(wrapper.find('.ant-form-item-label label').at(0).text()).not.toContain(':');
    expect(wrapper.find('.ant-form-item-label label').at(1).text()).not.toContain('：');
  });

  it('should not remove duplicated user input colon when props colon is false', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      null,
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label:', colon: false },
        'input'
      ),
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label\uFF1A', colon: false },
        'input'
      )
    ));
    expect(wrapper.find('.ant-form-item-label label').at(0).text()).toContain(':');
    expect(wrapper.find('.ant-form-item-label label').at(1).text()).toContain('：');
  });

  it('should not remove duplicated user input colon when layout is vertical', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      { layout: 'vertical' },
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label:' },
        'input'
      ),
      _react2.default.createElement(
        _2.default.Item,
        { label: 'label\uFF1A' },
        'input'
      )
    ));
    expect(wrapper.find('.ant-form-item-label label').at(0).text()).toContain(':');
    expect(wrapper.find('.ant-form-item-label label').at(1).text()).toContain('：');
  });

  it('should has dom with .ant-form-item-control-wrapper', function () {
    var formItemLayout = {
      labelCol: { span: 6 },
      wrapperCol: { span: 14 }
    };
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      null,
      _react2.default.createElement(
        _2.default.Item,
        formItemLayout,
        'input'
      ),
      _react2.default.createElement(
        _2.default.Item,
        null,
        'input'
      )
    ));
    expect(wrapper.find('.ant-form-item-control-wrapper').length).toBe(2);
    expect(wrapper.find('.ant-form-item-control-wrapper.ant-col-14').length).toBe(1);
  });

  // https://github.com/ant-design/ant-design/issues/7351
  it('focus correct input when click label', function () {
    var Form1 = _2.default.create()(function (_ref) {
      var form = _ref.form;
      return _react2.default.createElement(
        _2.default,
        null,
        _react2.default.createElement(
          _2.default.Item,
          { label: 'label 1' },
          form.getFieldDecorator('test')(_react2.default.createElement('input', null))
        )
      );
    });
    var Form2 = _2.default.create()(function (_ref2) {
      var form = _ref2.form;
      return _react2.default.createElement(
        _2.default,
        null,
        _react2.default.createElement(
          _2.default.Item,
          { label: 'label 2' },
          form.getFieldDecorator('test2')(_react2.default.createElement('input', null))
        )
      );
    });
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(Form1, null),
      _react2.default.createElement(Form2, null)
    ));
    wrapper.find('Form label').at(0).simulate('click');
    expect(wrapper.find('Form input').at(0).node).toBe(document.activeElement);
    wrapper.find('Form label').at(1).simulate('click');
    expect(wrapper.find('Form input').at(1).node).toBe(document.activeElement);
  });

  // https://github.com/ant-design/ant-design/issues/7693
  it('should not throw error when is not a valid id', function () {
    var Form1 = _2.default.create()(function (_ref3) {
      var form = _ref3.form;
      return _react2.default.createElement(
        _2.default,
        null,
        _react2.default.createElement(
          _2.default.Item,
          { label: 'label 1' },
          form.getFieldDecorator('member[0].name.firstname')(_react2.default.createElement('input', null))
        )
      );
    });
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(Form1, null));
    expect(function () {
      wrapper.find('Form label').at(0).simulate('click');
    }).not.toThrow();
    expect(wrapper.find('Form input').at(0).node).toBe(document.activeElement);
  });
});