'use strict';

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.useFakeTimers();

describe('notification', function () {
  afterEach(function () {
    _2.default.destroy();
  });

  it('should be able to hide manually', function () {
    _2.default.open({
      message: 'Notification Title',
      duration: 0,
      key: '1'
    });
    _2.default.open({
      message: 'Notification Title',
      duration: 0,
      key: '2'
    });
    expect(document.querySelectorAll('.ant-notification-notice').length).toBe(2);
    _2.default.close('1');
    jest.runAllTimers();
    expect(document.querySelectorAll('.ant-notification-notice').length).toBe(1);
    _2.default.close('2');
    jest.runAllTimers();
    expect(document.querySelectorAll('.ant-notification-notice').length).toBe(0);
  });

  it('should be able to destroy globally', function () {
    _2.default.open({
      message: 'Notification Title',
      duration: 0
    });
    _2.default.open({
      message: 'Notification Title',
      duration: 0
    });
    expect(document.querySelectorAll('.ant-notification').length).toBe(1);
    expect(document.querySelectorAll('.ant-notification-notice').length).toBe(2);
    _2.default.destroy();
    expect(document.querySelectorAll('.ant-notification').length).toBe(0);
    expect(document.querySelectorAll('.ant-notification-notice').length).toBe(0);
  });

  it('should be able to destroy after config', function () {
    _2.default.config({
      bottom: 100
    });
    _2.default.destroy();
  });

  it('should be able to open with icon', function () {
    var openNotificationWithIcon = function openNotificationWithIcon(type) {
      var iconPrefix = '.ant-notification-notice-icon';
      _2.default[type]({
        message: 'Notification Title',
        duration: 0,
        description: 'This is the content of the notification.'
      });
      expect(document.querySelectorAll(iconPrefix + '-' + type).length).toBe(1);
    };
    ['success', 'info', 'warning', 'error'].forEach(function (type) {
      openNotificationWithIcon(type);
    });
  });
});