'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _radio = require('../radio');

var _radio2 = _interopRequireDefault(_radio);

var _group = require('../group');

var _group2 = _interopRequireDefault(_group);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Radio', function () {
  function createRadioGroup(props) {
    return _react2.default.createElement(
      _group2.default,
      props,
      _react2.default.createElement(
        _radio2.default,
        { value: 'A' },
        'A'
      ),
      _react2.default.createElement(
        _radio2.default,
        { value: 'B' },
        'B'
      ),
      _react2.default.createElement(
        _radio2.default,
        { value: 'C' },
        'C'
      )
    );
  }

  function createRadioGroupByOption(props) {
    var options = [{ label: 'A', value: 'A' }, { label: 'B', value: 'B' }, { label: 'C', value: 'C' }];

    return _react2.default.createElement(_group2.default, (0, _extends3.default)({}, props, {
      options: options
    }));
  }

  it('responses hover events', function () {
    var onMouseEnter = jest.fn();
    var onMouseLeave = jest.fn();

    var wrapper = (0, _enzyme.shallow)(_react2.default.createElement(
      _group2.default,
      {
        onMouseEnter: onMouseEnter,
        onMouseLeave: onMouseLeave
      },
      _react2.default.createElement(_radio2.default, null)
    ));

    wrapper.simulate('mouseenter');
    expect(onMouseEnter).toHaveBeenCalled();

    wrapper.simulate('mouseleave');
    expect(onMouseLeave).toHaveBeenCalled();
  });

  it('fire change events when value changes', function () {
    var onChange = jest.fn();

    var wrapper = (0, _enzyme.mount)(createRadioGroup({
      onChange: onChange
    }));
    var radios = wrapper.find('input');

    // uncontrolled component
    wrapper.setState({ value: 'B' });
    radios.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(1);

    // controlled component
    wrapper.setProps({ value: 'A' });
    radios.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(2);
  });

  it('won\'t fire change events when value not changes', function () {
    var onChange = jest.fn();

    var wrapper = (0, _enzyme.mount)(createRadioGroup({
      onChange: onChange
    }));
    var radios = wrapper.find('input');

    // uncontrolled component
    wrapper.setState({ value: 'B' });
    radios.at(1).simulate('change');
    expect(onChange.mock.calls.length).toBe(0);

    // controlled component
    wrapper.setProps({ value: 'A' });
    radios.at(0).simulate('change');
    expect(onChange.mock.calls.length).toBe(0);
  });

  it('optional should correct render', function () {
    var wrapper = (0, _enzyme.mount)(createRadioGroupByOption());
    var radios = wrapper.find('input');

    expect(radios.length).toBe(3);
  });

  it('all children should have a name property', function () {
    var GROUP_NAME = 'radiogroup';
    var wrapper = (0, _enzyme.mount)(createRadioGroup({ name: GROUP_NAME }));

    expect(wrapper.find('input[type="radio"]').forEach(function (el) {
      expect(el.props().name).toEqual(GROUP_NAME);
    }));
  });
});