'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _createStore = require('../createStore');

var _createStore2 = _interopRequireDefault(_createStore);

var _SelectionBox = require('../SelectionBox');

var _SelectionBox2 = _interopRequireDefault(_SelectionBox);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('SelectionBox', function () {
  it('unchecked by selectedRowKeys ', function () {
    var store = (0, _createStore2.default)({
      selectedRowKeys: [],
      selectionDirty: false
    });

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_SelectionBox2.default, {
      store: store,
      rowIndex: '1',
      disabled: false,
      onChange: function onChange() {},
      defaultSelection: []
    }));

    expect(wrapper.state()).toEqual({ checked: false });
  });

  it('checked by selectedRowKeys ', function () {
    var store = (0, _createStore2.default)({
      selectedRowKeys: ['1'],
      selectionDirty: false
    });

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_SelectionBox2.default, {
      store: store,
      rowIndex: '1',
      disabled: false,
      onChange: function onChange() {},
      defaultSelection: []
    }));

    expect(wrapper.state()).toEqual({ checked: true });
  });

  it('checked by defaultSelection', function () {
    var store = (0, _createStore2.default)({
      selectedRowKeys: [],
      selectionDirty: false
    });

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_SelectionBox2.default, {
      store: store,
      rowIndex: '1',
      disabled: false,
      onChange: function onChange() {},
      defaultSelection: ['1']
    }));

    expect(wrapper.state()).toEqual({ checked: true });
  });

  it('checked when store change', function () {
    var store = (0, _createStore2.default)({
      selectedRowKeys: [],
      selectionDirty: false
    });

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_SelectionBox2.default, {
      store: store,
      rowIndex: '1',
      disabled: false,
      onChange: function onChange() {},
      defaultSelection: []
    }));

    store.setState({
      selectedRowKeys: ['1'],
      selectionDirty: true
    });

    expect(wrapper.state()).toEqual({ checked: true });
  });
});