'use strict';

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Table.filter', function () {
  var filterFn = function filterFn(value, record) {
    return record.name.indexOf(value) !== -1;
  };
  var column = {
    title: 'Name',
    dataIndex: 'name',
    filters: [{ text: 'Boy', value: 'boy' }, { text: 'Girl', value: 'girl' }, {
      text: 'Title',
      value: 'title',
      children: [{ text: 'Designer', value: 'designer' }, { text: 'Coder', value: 'coder' }]
    }],
    onFilter: filterFn
  };

  var data = [{ key: 0, name: 'Jack' }, { key: 1, name: 'Lucy' }, { key: 2, name: 'Tom' }, { key: 3, name: 'Jerry' }];

  function createTable(props) {
    return _react2.default.createElement(_2.default, (0, _extends3.default)({
      columns: [column],
      dataSource: data,
      pagination: false
    }, props));
  }

  function renderedNames(wrapper) {
    return wrapper.find('TableRow').map(function (row) {
      return row.props().record.name;
    });
  }

  it('renders filter correctly', function () {
    var wrapper = (0, _enzyme.render)(createTable());

    expect(wrapper).toMatchSnapshot();
  });

  it('renders menu correctly', function () {
    var wrapper = (0, _enzyme.mount)(createTable());
    var dropdownWrapper = (0, _enzyme.render)(wrapper.find('Trigger').node.getComponent());
    expect(dropdownWrapper).toMatchSnapshot();
  });

  it('renders radio filter correctly', function () {
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filterMultiple: false
      })]
    }));
    var dropdownWrapper = (0, _enzyme.render)(wrapper.find('Trigger').node.getComponent());
    expect(dropdownWrapper).toMatchSnapshot();
  });

  it('renders custom content correctly', function () {
    var filter = _react2.default.createElement(
      'div',
      { className: 'custom-filter-dropdown' },
      'custom filter'
    );
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filterDropdown: filter
      })]
    }));

    var dropdownWrapper = (0, _enzyme.render)(wrapper.find('Trigger').node.getComponent());
    expect(dropdownWrapper).toMatchSnapshot();
  });

  it('can be controlled by filterDropdownVisible', function () {
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filterDropdownVisible: true
      })]
    }));
    var dropdown = wrapper.find('Dropdown').first();

    expect(dropdown.props().visible).toBe(true);
    wrapper.setProps({
      columns: [(0, _extends3.default)({}, column, {
        filterDropdownVisible: false
      })]
    });
    expect(dropdown.props().visible).toBe(false);
  });

  it('fires change event when visible change', function () {
    var handleChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        onFilterDropdownVisibleChange: handleChange
      })]
    }));

    wrapper.find('Dropdown').first().simulate('click');

    expect(handleChange).toBeCalledWith(true);
  });

  it('can be controlled by filteredValue', function () {
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filteredValue: ['Lucy']
      })]
    }));

    expect(wrapper.find('tbody tr').length).toBe(1);
    wrapper.setProps({
      columns: [(0, _extends3.default)({}, column, {
        filteredValue: []
      })]
    });
    expect(wrapper.find('tbody tr').length).toBe(4);
  });

  it('can be controlled by filteredValue null', function () {
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filteredValue: ['Lucy']
      })]
    }));

    expect(wrapper.find('tbody tr').length).toBe(1);
    wrapper.setProps({
      columns: [(0, _extends3.default)({}, column, {
        filteredValue: null
      })]
    });
    expect(wrapper.find('tbody tr').length).toBe(4);
  });

  it('fires change event', function () {
    var handleChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(createTable({ onChange: handleChange }));
    var dropdownWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());

    dropdownWrapper.find('MenuItem').first().simulate('click');
    dropdownWrapper.find('.confirm').simulate('click');

    expect(handleChange).toBeCalledWith({}, { name: ['boy'] }, {});
  });

  it('three levels menu', function () {
    var filters = [{ text: 'Upper', value: 'Upper' }, { text: 'Lower', value: 'Lower' }, {
      text: 'Level2',
      value: 'Level2',
      children: [{ text: 'Large', value: 'Large' }, { text: 'Small', value: 'Small' }, {
        text: 'Level3',
        value: 'Level3',
        children: [{ text: 'Black', value: 'Black' }, { text: 'White', value: 'White' }, { text: 'Jack', value: 'Jack' }]
      }]
    }];
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, {
        filters: filters
      })]
    }));
    var dropdownWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());
    dropdownWrapper.find('.ant-dropdown-menu-submenu-title').at(0).simulate('mouseEnter');
    dropdownWrapper.find('.ant-dropdown-menu-submenu-title').at(1).simulate('mouseEnter');
    dropdownWrapper.find('MenuItem').last().simulate('click');
    dropdownWrapper.find('.confirm').simulate('click');
    expect(renderedNames(wrapper)).toEqual(['Jack']);
  });

  it('works with JSX in controlled mode', function () {
    var Column = _2.default.Column;

    var App = function (_React$Component) {
      (0, _inherits3.default)(App, _React$Component);

      function App() {
        var _ref;

        var _temp, _this, _ret;

        (0, _classCallCheck3.default)(this, App);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, (_ref = App.__proto__ || (0, _getPrototypeOf2.default)(App)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
          filters: {}
        }, _this.handleChange = function (pagination, filters) {
          _this.setState({ filters: filters });
        }, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret);
      }

      (0, _createClass3.default)(App, [{
        key: 'render',
        value: function render() {
          return _react2.default.createElement(
            _2.default,
            { dataSource: data, onChange: this.handleChange },
            _react2.default.createElement(Column, {
              title: 'name',
              dataIndex: 'name',
              key: 'name',
              filters: [{ text: 'Jack', value: 'Jack' }, { text: 'Lucy', value: 'Lucy' }],
              filteredValue: this.state.filters.name,
              onFilter: filterFn
            })
          );
        }
      }]);
      return App;
    }(_react2.default.Component);

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(App, null));
    var dropdownWrapper = (0, _enzyme.mount)(wrapper.find('Trigger').node.getComponent());

    dropdownWrapper.find('MenuItem').first().simulate('click');
    dropdownWrapper.find('.confirm').simulate('click');
    expect(renderedNames(wrapper)).toEqual(['Jack']);

    dropdownWrapper.find('.clear').simulate('click');
    expect(renderedNames(wrapper)).toEqual(['Jack', 'Lucy', 'Tom', 'Jerry']);
  });

  it('works with grouping columns in controlled mode', function () {
    var columns = [{
      title: 'group',
      key: 'group',
      children: [{
        title: 'Name',
        dataIndex: 'name',
        key: 'name',
        filters: [{ text: 'Jack', value: 'Jack' }, { text: 'Lucy', value: 'Lucy' }],
        onFilter: filterFn,
        filteredValue: ['Jack']
      }, {
        title: 'Age',
        dataIndex: 'age',
        key: 'age'
      }]
    }];
    var testData = [{ key: 0, name: 'Jack', age: 11 }, { key: 1, name: 'Lucy', age: 20 }, { key: 2, name: 'Tom', age: 21 }, { key: 3, name: 'Jerry', age: 22 }];
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { columns: columns, dataSource: testData }));

    expect(renderedNames(wrapper)).toEqual(['Jack']);
  });
});