'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('..');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Table.sorter', function () {
  var sorterFn = function sorterFn(a, b) {
    return a.name[0].charCodeAt() - b.name[0].charCodeAt();
  };

  var column = {
    title: 'Name',
    dataIndex: 'name',
    sorter: sorterFn
  };

  var data = [{ key: 0, name: 'Jack' }, { key: 1, name: 'Lucy' }, { key: 2, name: 'Tom' }, { key: 3, name: 'Jerry' }];

  function createTable(props) {
    return _react2.default.createElement(_2.default, (0, _extends3.default)({
      columns: [column],
      dataSource: data,
      pagination: false
    }, props));
  }

  function renderedNames(wrapper) {
    return wrapper.find('TableRow').map(function (row) {
      return row.props().record.name;
    });
  }

  it('renders sorter icon correctly', function () {
    var wrapper = (0, _enzyme.render)(createTable());
    expect(wrapper.find('thead')).toMatchSnapshot();
  });

  it('sort records', function () {
    var wrapper = (0, _enzyme.mount)(createTable());

    wrapper.find('.ant-table-column-sorter-up').simulate('click');
    expect(renderedNames(wrapper)).toEqual(['Jack', 'Jerry', 'Lucy', 'Tom']);

    wrapper.find('.ant-table-column-sorter-down').simulate('click');
    expect(renderedNames(wrapper)).toEqual(['Tom', 'Lucy', 'Jack', 'Jerry']);
  });

  it('can be controlled by sortOrder', function () {
    var wrapper = (0, _enzyme.mount)(createTable({
      columns: [(0, _extends3.default)({}, column, { sortOrder: 'ascend' })]
    }));
    expect(renderedNames(wrapper)).toEqual(['Jack', 'Jerry', 'Lucy', 'Tom']);
  });

  it('fires change event', function () {
    var handleChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(createTable({ onChange: handleChange }));

    wrapper.find('.ant-table-column-sorter-up').simulate('click');

    var sorter = handleChange.mock.calls[0][2];
    expect(sorter.column.dataIndex).toBe('name');
    expect(sorter.order).toBe('ascend');
    expect(sorter.field).toBe('name');
    expect(sorter.columnKey).toBe('name');
  });

  it('works with grouping columns in controlled mode', function () {
    var columns = [{
      title: 'group',
      key: 'group',
      children: [{
        title: 'Name',
        dataIndex: 'name',
        key: 'name',
        sorter: sorterFn,
        sortOrder: 'descend'
      }, {
        title: 'Age',
        dataIndex: 'age',
        key: 'age'
      }]
    }];
    var testData = [{ key: 0, name: 'Jack', age: 11 }, { key: 1, name: 'Lucy', age: 20 }, { key: 2, name: 'Tom', age: 21 }, { key: 3, name: 'Jerry', age: 22 }];
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(_2.default, { columns: columns, dataSource: testData }));

    expect(renderedNames(wrapper)).toEqual(['Tom', 'Lucy', 'Jack', 'Jerry']);
  });
});