'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('..');

var _2 = _interopRequireDefault(_);

var _button = require('../../button');

var _button2 = _interopRequireDefault(_button);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Tooltip', function () {
  it('check `onVisibleChange` arguments', function () {
    var onVisibleChange = jest.fn();

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: '',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0,
        onVisibleChange: onVisibleChange
      },
      _react2.default.createElement(
        'div',
        null,
        'Hello world!'
      )
    ));

    // `title` is empty.
    var div = wrapper.find('div').at(0);
    div.simulate('mouseenter');
    expect(onVisibleChange).not.toHaveBeenCalled();
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);

    div.simulate('mouseleave');
    expect(onVisibleChange).not.toHaveBeenCalled();
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);

    // update `title` value.
    wrapper.setProps({ title: 'Have a nice day!' });
    wrapper.simulate('mouseenter');
    expect(onVisibleChange).toHaveBeenLastCalledWith(true);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(true);

    wrapper.simulate('mouseleave');
    expect(onVisibleChange).toHaveBeenLastCalledWith(false);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);

    // add `visible` props.
    wrapper.setProps({ visible: false });
    wrapper.simulate('mouseenter');
    expect(onVisibleChange).toHaveBeenLastCalledWith(true);
    var lastCount = onVisibleChange.mock.calls.length;
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);

    // always trigger onVisibleChange
    wrapper.simulate('mouseleave');
    expect(onVisibleChange.mock.calls.length).toBe(lastCount); // no change with lastCount
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);
  });

  it('should hide when mouse leave native disabled button', function () {
    var onVisibleChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: 'xxxxx',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0,
        onVisibleChange: onVisibleChange
      },
      _react2.default.createElement(
        'button',
        { disabled: true },
        'Hello world!'
      )
    ));

    expect(wrapper.find('span')).toHaveLength(1);
    var button = wrapper.find('span').at(0);
    button.simulate('mouseenter');
    expect(onVisibleChange).toBeCalledWith(true);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(true);

    button.simulate('mouseleave');
    expect(onVisibleChange).toBeCalledWith(false);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);
  });

  it('should hide when mouse leave antd disabled Button', function () {
    var onVisibleChange = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: 'xxxxx',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0,
        onVisibleChange: onVisibleChange
      },
      _react2.default.createElement(
        _button2.default,
        { disabled: true },
        'Hello world!'
      )
    ));

    expect(wrapper.getDOMNode().tagName).toBe('SPAN');
    var button = wrapper.find('span').at(0);
    button.simulate('mouseenter');
    expect(onVisibleChange).toBeCalledWith(true);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(true);

    button.simulate('mouseleave');
    expect(onVisibleChange).toBeCalledWith(false);
    expect(wrapper.ref('tooltip').prop('visible')).toBe(false);
  });

  it('should render disabled Button style properly', function () {
    var wrapper1 = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      { title: 'xxxxx' },
      _react2.default.createElement(
        _button2.default,
        { disabled: true },
        'Hello world!'
      )
    ));
    var wrapper2 = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      { title: 'xxxxx' },
      _react2.default.createElement(
        _button2.default,
        { disabled: true, style: { display: 'block' } },
        'Hello world!'
      )
    ));
    expect(wrapper1.getDOMNode().style.display).toBe('inline-block');
    expect(wrapper2.getDOMNode().style.display).toBe('block');
  });

  it('should not wrap span when trigger is not hover', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: 'xxxxx',
        trigger: 'click',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0
      },
      _react2.default.createElement(
        'button',
        { disabled: true },
        'Hello world!'
      )
    ));

    expect(wrapper.find('span')).toHaveLength(0);
  });

  it('should works for arrowPointAtCenter', function () {
    var arrowWidth = 5;
    var horizontalArrowShift = 16;
    var triggerWidth = 200;

    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: 'xxxxx',
        trigger: 'click',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0,
        placement: 'bottomLeft'
      },
      _react2.default.createElement(
        'button',
        { style: { width: triggerWidth } },
        'Hello world!'
      )
    ));
    wrapper.find('button').at(0).simulate('click');
    var popupLeftDefault = parseInt(wrapper.node.getPopupDomNode().style.left, 10);

    var wrapper2 = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        title: 'xxxxx',
        trigger: 'click',
        mouseEnterDelay: 0,
        mouseLeaveDelay: 0,
        placement: 'bottomLeft',
        arrowPointAtCenter: true
      },
      _react2.default.createElement(
        'button',
        { style: { width: triggerWidth } },
        'Hello world!'
      )
    ));
    wrapper2.find('button').at(0).simulate('click');
    var popupLeftArrowPointAtCenter = parseInt(wrapper2.node.getPopupDomNode().style.left, 10);
    expect(popupLeftArrowPointAtCenter - popupLeftDefault).toBe(triggerWidth / 2 - horizontalArrowShift - arrowWidth);
  });
});