'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ = require('..');

var _2 = _interopRequireDefault(_);

var _requests = require('./requests');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var delay = function delay(timeout) {
  return new _promise2.default(function (resolve) {
    return setTimeout(resolve, timeout);
  });
};

var fileList = [{
  uid: -1,
  name: 'xxx.png',
  status: 'done',
  url: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png',
  thumbUrl: 'https://zos.alipayobjects.com/rmsportal/IQKRngzUuFzJzGzRJXUs.png'
}, {
  uid: -2,
  name: 'yyy.png',
  status: 'done',
  url: 'https://zos.alipayobjects.com/rmsportal/IQKRngzUuFzJzGzRJXUs.png',
  thumbUrl: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png'
}];

describe('Upload List', function () {
  // https://github.com/ant-design/ant-design/issues/4653
  it('should use file.thumbUrl for <img /> in priority', function () {
    var wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      { defaultFileList: fileList, listType: 'picture' },
      _react2.default.createElement(
        'button',
        null,
        'upload'
      )
    ));
    fileList.forEach(function (file, i) {
      var linkNode = wrapper.find('.ant-upload-list-item-thumbnail').at(i);
      var imgNode = wrapper.find('.ant-upload-list-item-thumbnail img').at(i);
      expect(linkNode.prop('href')).toBe(file.url);
      expect(imgNode.prop('src')).toBe(file.thumbUrl);
    });
  });

  // https://github.com/ant-design/ant-design/issues/7269
  it('should remove correct item when uid is 0', (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    var list, wrapper;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            list = [{
              uid: 0,
              name: 'xxx.png',
              status: 'done',
              url: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png',
              thumbUrl: 'https://zos.alipayobjects.com/rmsportal/IQKRngzUuFzJzGzRJXUs.png'
            }, {
              uid: 1,
              name: 'xxx.png',
              status: 'done',
              url: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png',
              thumbUrl: 'https://zos.alipayobjects.com/rmsportal/IQKRngzUuFzJzGzRJXUs.png'
            }];
            wrapper = (0, _enzyme.mount)(_react2.default.createElement(
              _2.default,
              { defaultFileList: list },
              _react2.default.createElement(
                'button',
                null,
                'upload'
              )
            ));

            expect(wrapper.find('.ant-upload-list-item').length).toBe(2);
            wrapper.find('.ant-upload-list-item').at(0).find('.anticon-cross').simulate('click');
            _context.next = 6;
            return delay(400);

          case 6:
            expect(wrapper.find('.ant-upload-list-item').length).toBe(1);

          case 7:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  })));

  it('should be uploading when upload a file', function (done) {
    var wrapper = void 0;
    var onChange = function onChange(_ref2) {
      var file = _ref2.file;

      if (file.status === 'uploading') {
        expect(wrapper.render()).toMatchSnapshot();
      }
      if (file.status === 'done') {
        expect(wrapper.render()).toMatchSnapshot();
        done();
      }
    };
    wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        action: 'http://jsonplaceholder.typicode.com/posts/',
        onChange: onChange,
        customRequest: _requests.successRequest
      },
      _react2.default.createElement(
        'button',
        null,
        'upload'
      )
    ));
    wrapper.find('input').simulate('change', {
      target: {
        files: [{ filename: 'foo.png' }]
      }
    });
  });

  it('handle error', function (done) {
    var wrapper = void 0;
    var onChange = function onChange(_ref3) {
      var file = _ref3.file;

      if (file.status !== 'uploading') {
        expect(wrapper.render()).toMatchSnapshot();
        done();
      }
    };
    wrapper = (0, _enzyme.mount)(_react2.default.createElement(
      _2.default,
      {
        action: 'http://jsonplaceholder.typicode.com/posts/',
        onChange: onChange,
        customRequest: _requests.errorRequest
      },
      _react2.default.createElement(
        'button',
        null,
        'upload'
      )
    ));
    wrapper.find('input').simulate('change', {
      target: {
        files: [{ filename: 'foo.png' }]
      }
    });
  });
});